@@ -779,6 +779,7 @@ There should be no more than seven characters after the final `/'."
 
 		  (jka-compr-ccrypt-call-process 
 		   uncompress-command
+		   nil
 		   (concat uncompress-message
 			   " " base-name)
 		   local-file
@@ -1030,6 +1031,15 @@ The return value is the entry in `file-name-handler-alist' for jka-compr-ccrypt.
 
     installed))
 
+;; since jka-compr-ccrypt provides strictly a superset of the
+;; functionality of jka-compr, override the jka-compr testing routines
+;; to make info.el happy. -JR1
+(defun jka-compr-installed-p ()
+  (jka-compr-ccrypt-installed-p))
+(provide 'jka-compr)
+(defun jka-compr-get-compression-info (fullname)
+  (jka-compr-ccrypt-get-compression-info fullname))
+
 
 ;;; Add the file I/O hook if it does not already exist.
 ;;; Make sure that jka-compr-ccrypt-file-name-handler-entry is eq to the
