@@ -1,5 +1,9 @@
+/* Copyright (C) 2000-2004 Peter Selinger.
+   This file is part of ccrypt. It is free software and it is covered
+   by the GNU general public license. See the file COPYING for details. */
+
 /* rijndael.c - optimized version of the Rijndeal cipher */
-/* $Id: rijndael.c,v 1.4 2002/01/30 02:36:34 selinger Exp $ */
+/* $Id: rijndael.c,v 1.9 2003/08/25 18:06:20 selinger Exp $ */
 
 /* derived from original source: rijndael-alg-ref.c   v2.0   August '99
  * Reference ANSI C code for NIST competition
@@ -7,25 +11,22 @@
  *          Vincent Rijmen
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "rijndael.h"
 
 static int xshifts[3][2][4] = {
-  0,1,2,3,
-  0,3,2,1,
-  
-  0,1,2,3,
-  0,5,4,3,
+  { { 0,1,2,3 },
+    { 0,3,2,1 } },
 
-  0,1,3,4,
-  0,7,5,4,
+  { { 0,1,2,3 },
+    { 0,5,4,3 } },
+
+  { { 0,1,3,4 },
+    { 0,7,5,4 } },
 };
 
 /* Exor corresponding text input and round key input bytes */
 /* the result is written to res, which can be the same as a */
-void xKeyAddition(word8 res[MAXBC][4], word8 a[MAXBC][4], 
+static void xKeyAddition(word8 res[MAXBC][4], word8 a[MAXBC][4], 
 		  word32 rk[MAXBC], word8 BC) {
   int j;
   
@@ -35,7 +36,7 @@ void xKeyAddition(word8 res[MAXBC][4], word8 a[MAXBC][4],
 
 /* shift rows a, return result in res. This avoids having to copy a
    tmp array back to a. res must not be a. */
-void xShiftRow(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4], 
+static void xShiftRow(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4], 
 	       word8 BC)
 {
   /* Row 0 remains unchanged
@@ -54,7 +55,7 @@ void xShiftRow(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4],
   }
 }
 
-void xSubstitution(word8 a[MAXBC][4], word8 box[256], word8 BC) {
+static void xSubstitution(word8 a[MAXBC][4], word8 box[256], word8 BC) {
   /* Replace every byte of the input by the byte at that place
    * in the nonlinear S-box
    */
@@ -74,7 +75,7 @@ void xSubstitution(word8 a[MAXBC][4], word8 box[256], word8 BC) {
    faster on most platforms. */
 
 /* do ShiftRow and Substitution together. res must not be a. */
-void xShiftSubst(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4], 
+static void xShiftSubst(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4], 
 		 word8 BC, word8 box[256]) {
   int i, j;
   int s;
@@ -93,7 +94,7 @@ void xShiftSubst(word8 res[MAXBC][4], word8 a[MAXBC][4], int shift[4],
 
 /* Mix the four bytes of every column in a linear way */
 /* the result is written to res, which may equal a */
-void xMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
+static void xMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
   int j;
   word32 b;
 
@@ -107,7 +108,7 @@ void xMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
 }
 
 /* do MixColumn and KeyAddition together */
-void xMixAdd(word8 res[MAXBC][4], word8 a[MAXBC][4], word32 rk[MAXBC], 
+static void xMixAdd(word8 res[MAXBC][4], word8 a[MAXBC][4], word32 rk[MAXBC], 
 	     word8 BC) {
   int j;
   word32 b;
@@ -125,7 +126,7 @@ void xMixAdd(word8 res[MAXBC][4], word8 a[MAXBC][4], word32 rk[MAXBC],
 /* Mix the four bytes of every column in a linear way
  * This is the opposite operation of xMixColumn */
 /* the result is written to res, which may equal a */
-void xInvMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
+static void xInvMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
   int j;
   word32 b;
   
@@ -139,7 +140,7 @@ void xInvMixColumn(word8 res[MAXBC][4], word8 a[MAXBC][4], word8 BC) {
 }
 
 /* do KeyAddition and InvMixColumn together */
-void xAddInvMix(word8 res[MAXBC][4], word8 a[MAXBC][4], word32 rk[MAXBC], 
+static void xAddInvMix(word8 res[MAXBC][4], word8 a[MAXBC][4], word32 rk[MAXBC], 
 		  word8 BC) {
   int j;
   word32 b;
