@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2003 Peter Selinger.
+/* Copyright (C) 2000-2004 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
@@ -6,7 +6,7 @@
    optionally recursing through directory structure, and doing
    whatever action is required for encrypting/decrypting files in the
    various modes */
-/* $Id: traverse.c,v 1.11 2003/08/25 19:03:29 selinger Exp $ */ 
+/* $Id: traverse.c,v 1.13 2004/03/29 04:14:55 selinger Exp $ */ 
 
 #define _FILE_OFFSET_BITS 64  /* turn off 2GB limit on file size */
 
@@ -718,7 +718,7 @@ static void file_action(char *filename) {
     case ENCRYPT: default:
       if (cmd.strictsuffix && cmd.suffix[0] != 0 && has_suffix(infile, cmd.suffix)) {
 	if (cmd.verbose>=0) {
-	  fprintf(stderr, "%s: %s already has %s suffix -- ignoring\n", cmd.name, infile, cmd.suffix); 
+	  fprintf(stderr, "%s: %s already has %s suffix -- ignored\n", cmd.name, infile, cmd.suffix); 
 	  strict_warnings++;
 	}
 	goto done;
